Module variable

Module variable 

Structs

RcValueDeserializer
VariableDeserializer
VariableMap

Enums

MapIter
RcValue
RefDeserializeError
Variable
VariableConversionError
VariableType

Traits

DynamicVariable
ToVariable
VariableMapExt
A convenience trait that can be used together with the type aliases defined to get access to the new() and with_capacity() methods for the HashMap type alias.

Type Aliases

RcCell
Symbol

Derive Macros

ToVariable