VariableMapExt

Trait VariableMapExt 

pub trait VariableMapExt {
    // Required methods
    fn new() -> Self;
    fn with_capacity(capacity: usize) -> Self;
}
A convenience trait that can be used together with the type aliases defined to get access to the new() and with_capacity() methods for the HashMap type alias.

Required Methods

fn new() -> Self

Constructs a new HashMap

fn with_capacity(capacity: usize) -> Self

Constructs a new HashMap with a given initial capacity

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<K, V, S> HashMapExt for HashMap<K, V, S>
where S: BuildHasher + Default,

Available on crate feature std only.
Source

fn new() -> HashMap<K, V, S>

Source

fn with_capacity(capacity: usize) -> HashMap<K, V, S>

Implementors